==> haskell-file-embed-0.0.10.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.10.1
id: file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK
key: file-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.
category: Data
abi: 89438ae516d9703c3ac089ebacbbe70d
exposed: True
exposed-modules:
    Data.FileEmbed
import-dirs: /usr/lib/ghc-8.4.3/site-local/file-embed-0.0.10.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/file-embed-0.0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/file-embed-0.0.10.1
hs-libraries: HSfile-embed-0.0.10.1-JBj0CTa3b3pL2aTV19QFZK
depends:
    base-4.11.1.0 bytestring-0.10.8.2 directory-1.3.1.5
    template-haskell-2.13.0.0 filepath-1.4.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-file-embed-0.0.11-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-file-embed.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: file-embed
version: 0.0.11
id: file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
key: file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: https://github.com/snoyberg/file-embed
synopsis: Use Template Haskell to embed file contents directly.
description:
    Use Template Haskell to read a file or all the files in a
    directory, and turn them into (path, bytestring) pairs
    embedded in your Haskell code.
category: Data
abi: 46cca7bb0548d8ae1738b3dc324c7440
exposed: True
exposed-modules:
    Data.FileEmbed
import-dirs: /usr/lib/ghc-8.4.3/site-local/file-embed-0.0.11
library-dirs: /usr/lib/ghc-8.4.3/site-local/file-embed-0.0.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/file-embed-0.0.11
hs-libraries: HSfile-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
depends:
    base-4.11.1.0 bytestring-0.10.8.2 directory-1.3.1.5
    template-haskell-2.13.0.0 filepath-1.4.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
haddock-interfaces: /usr/share/doc/haskell-file-embed/html/file-embed.haddock
haddock-html: /usr/share/doc/haskell-file-embed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
